#include <iostream>
#include <set>
#include <string>

struct Person {
    std::string name;
    int age;

    // This is used for printing
    friend std::ostream& operator<<(std::ostream& os, const Person& p) {
        return os << p.name << " (" << p.age << ")";
    }
};

// Custom comparator for descending order of age
struct PersonComparator {
    bool operator()(const Person& a, const Person& b) const {
        if (a.age != b.age) {
            return a.age > b.age;  // Descending order of age
        }
        return a.name < b.name;  // Ascending order of name if ages are equal
    }
};

int main() {
    std::multiset<Person, PersonComparator> people;

    people.insert({"Alice", 30});
    people.insert({"Bob", 25});
    people.insert({"Charlie", 35});
    people.insert({"David", 30});
    people.insert({"Eve", 25});

    for (const auto& person : people) {
        std::cout << person << std::endl;
    }

    return 0;
}
